@@ -22,7 +22,7 @@ class MyReadingMangaInfo(Provider, Std):
         return v[::-1]
 
     def prepare_cookies(self):
-        self.cf_protect(self.get_url())
+        self.cf_scrape(self.get_url())
 
     def get_files(self):
         selector = '.entry-content div img,.entry-content p img'
